CREATE CACHED TABLE PRIMARY_KEY (
       KEY_NAME VARCHAR(50) NOT NULL
     , KEY_VALUE INTEGER DEFAULT '0' NOT NULL
     , PRIMARY KEY (KEY_NAME)
);

CREATE CACHED TABLE METRIC (
       ID INT NOT NULL
     , NAME VARCHAR(2500) NOT NULL
     , PARENT INT
     , PRIMARY KEY (ID)
     , CONSTRAINT "FK_METRIC_SQLC$PARENT" FOREIGN KEY (PARENT)
                  REFERENCES METRIC (ID) ON DELETE CASCADE ON UPDATE CASCADE
);
CREATE INDEX "IX_METRIC_SQLC$E_VALUE" ON METRIC (PARENT, NAME);

CREATE CACHED TABLE SLICE (
       ID INTEGER DEFAULT '0' NOT NULL
     , METRIC_ID INTEGER NOT NULL
     , TIME_FROM BIGINT NOT NULL
     , TIME_TO BIGINT NOT NULL
     , MEASUREMENTS DOUBLE NOT NULL
     , TOTAL DOUBLE NOT NULL
     , MIN_VALUE DOUBLE NOT NULL
     , MAX_VALUE DOUBLE NOT NULL
     , DEVIATION DOUBLE NOT NULL
     , PRIMARY KEY (ID)
     , CONSTRAINT "FK_SLICE_SQLC$METRIC" FOREIGN KEY (METRIC_ID)
                  REFERENCES METRIC (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_SLICE_SQLC$M_TIME_TO" ON SLICE (TIME_TO);

CREATE CACHED TABLE MEASUREMENT (
       ID INTEGER NOT NULL
     , SLICE_ID INTEGER NOT NULL
     , MEASUREMENT_VALUE DOUBLE NOT NULL
     , MEASUREMENT_TIME BIGINT NOT NULL
     , PRIMARY KEY (ID)
     , CONSTRAINT FK_MEASUREMENT_SLICE FOREIGN KEY (SLICE_ID)
                  REFERENCES SLICE (ID)
);
CREATE INDEX IX_MEASUREMENT_VALUE ON MEASUREMENT (MEASUREMENT_VALUE);

CREATE CACHED TABLE KINDRED (
       ANCESTOR INTEGER NOT NULL
     , DESCENDANT INTEGER NOT NULL
     , PRIMARY KEY (ANCESTOR, DESCENDANT)
     , CONSTRAINT FK_KINDRED_ANCESTOR FOREIGN KEY (ANCESTOR)
                  REFERENCES METRIC (ID) ON DELETE CASCADE
     , CONSTRAINT FK_KINDRED_DESCENDANT FOREIGN KEY (DESCENDANT)
                  REFERENCES METRIC (ID) ON DELETE CASCADE
);

